dimple-shiny: Shiny bindings for dimple

Description Usage Arguments

Description

Output and render functions for using dimple within Shiny applications and interactive Rmd documents.

Usage

1
2
3
dimpleOutput(outputId, width = "100%", height = "400px")

renderDimple(expr, env = parent.frame(), quoted = FALSE)

Arguments

outputId

output variable to read from

width,height

Must be a valid CSS unit (like "100%", "400px", "auto") or a number, which will be coerced to a string and have "px" appended.

expr

An expression that generates a dimple graph

env

The environment in which to evaluate expr.

quoted

Is expr a quoted expression (with quote())? This is useful if you want to save an expression in a variable.


jjallaire/dimple documentation built on May 19, 2019, 11:37 a.m.